package cn.com.infosec.asn1;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

public class DERBitString extends ASN1Object implements DERString {
   private static final char[] table = new char[]{'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'};
   protected byte[] data;
   protected int padBits;

   protected static int getPadBits(int bitString) {
      int var1 = 0;

      for(int var2 = 3; var2 >= 0; --var2) {
         if (var2 != 0) {
            int var3;
            if ((var3 = bitString >> var2 * 8) != 0) {
               var1 = var3 & 255;
               break;
            }
         } else if (bitString != 0) {
            var1 = bitString & 255;
            break;
         }
      }

      if (var1 == 0) {
         return 7;
      } else {
         for(bitString = 1; ((var1 <<= 1) & 255) != 0; ++bitString) {
         }

         return 8 - bitString;
      }
   }

   protected static byte[] getBytes(int bitString) {
      int var1 = 4;

      int var2;
      for(var2 = 3; var2 >= 1 && (bitString & 255 << var2 * 8) == 0; --var2) {
         --var1;
      }

      byte[] var3 = new byte[var1];

      for(var2 = 0; var2 < var1; ++var2) {
         var3[var2] = (byte)(bitString >> var2 * 8 & 255);
      }

      return var3;
   }

   public static DERBitString getInstance(Object obj) {
      if (obj != null && !(obj instanceof DERBitString)) {
         if (obj instanceof ASN1OctetString) {
            byte[] var10000 = ((ASN1OctetString)obj).getOctets();
            byte obj1 = var10000[0];
            byte[] var1 = new byte[var10000.length - 1];
            int var2 = var10000.length - 1;
            System.arraycopy(var10000, 1, var1, 0, var2);
            return new DERBitString(var1, obj1);
         } else if (obj instanceof ASN1TaggedObject) {
            return getInstance(((ASN1TaggedObject)obj).getObject());
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (DERBitString)obj;
      }
   }

   public static DERBitString getInstance(ASN1TaggedObject obj, boolean explicit) {
      return getInstance(obj.getObject());
   }

   protected DERBitString(byte data, int padBits) {
      (this.data = new byte[1])[0] = data;
      this.padBits = padBits;
   }

   public DERBitString(byte[] data, int padBits) {
      this.data = data;
      this.padBits = padBits;
   }

   public DERBitString(byte[] data) {
      this(data, 0);
   }

   public DERBitString(DEREncodable obj) {
      DERBitString var10000 = this;
      DERBitString var10001 = this;
      super();

      IOException var7;
      label33: {
         boolean var8;
         ByteArrayOutputStream var10002;
         try {
            var10002 = new ByteArrayOutputStream;
         } catch (IOException var4) {
            var7 = var4;
            var8 = false;
            break label33;
         }

         ByteArrayOutputStream var5;
         ByteArrayOutputStream var10003 = var5 = var10002;

         DEROutputStream var9;
         try {
            var10003.<init>();
            var9 = new DEROutputStream;
         } catch (IOException var3) {
            var7 = var3;
            var8 = false;
            break label33;
         }

         DEROutputStream var10004 = var9;
         DEROutputStream var10005 = var9;

         try {
            var10005.<init>(var5);
            var10004.writeObject(obj);
            var9.close();
            var10001.data = var10002.toByteArray();
            var10000.padBits = 0;
            return;
         } catch (IOException var2) {
            var7 = var2;
            var8 = false;
         }
      }

      IOException var6 = var7;
      throw new IllegalArgumentException("Error processing object : " + var6.toString());
   }

   public byte[] getBytes() {
      return this.data;
   }

   public int getPadBits() {
      return this.padBits;
   }

   public int intValue() {
      int var1 = 0;

      byte[] var3;
      for(int var2 = 0; var2 != (var3 = this.data).length && var2 != 4; ++var2) {
         var1 |= (var3[var2] & 255) << var2 * 8;
      }

      return var1;
   }

   void encode(DEROutputStream out) {
      DEROutputStream var10000 = out;
      byte[] var2;
      int out1;
      (var2 = new byte[out1 = this.getBytes().length + 1])[0] = (byte)this.getPadBits();
      byte[] var10001 = this.getBytes();
      int var3 = out1 - 1;
      System.arraycopy(var10001, 0, var2, 1, var3);
      var10000.writeEncoded(3, var2);
   }

   public int hashCode() {
      int var1 = 0;

      byte[] var3;
      for(int var2 = 0; var2 != (var3 = this.data).length; ++var2) {
         var1 ^= (var3[var2] & 255) << var2 % 4;
      }

      return var1;
   }

   protected boolean asn1Equals(DERObject o) {
      if (!(o instanceof DERBitString)) {
         return false;
      } else {
         DERBitString o1 = (DERBitString)o;
         if (this.data.length != o1.data.length) {
            return false;
         } else {
            byte[] var3;
            for(int var2 = 0; var2 != (var3 = this.data).length; ++var2) {
               if (var3[var2] != o1.data[var2]) {
                  return false;
               }
            }

            return this.padBits == o1.padBits;
         }
      }
   }

   public String getString() {
      StringBuffer var1;
      var1 = new StringBuffer.<init>("#");
      ByteArrayOutputStream var2;
      ByteArrayOutputStream var10000 = var2 = new ByteArrayOutputStream;
      var10000.<init>();
      DERBitString var10002 = this;
      ASN1OutputStream var10001 = new ASN1OutputStream(var2);

      try {
         var10001.writeObject(var10002);
      } catch (IOException var4) {
         throw new RuntimeException("internal error encoding BitString");
      }

      byte[] var5 = var10000.toByteArray();

      for(int var6 = 0; var6 != var5.length; ++var6) {
         char[] var3;
         char[] var7 = var3 = table;
         var1.append(var3[var5[var6] >>> 4 & 15]);
         var1.append(var7[var5[var6] & 15]);
      }

      return var1.toString();
   }

   public String toString() {
      return this.getString();
   }
}
